@@ -3,7 +3,7 @@ package Perlsac::rwsac ;
 use strict ;
 use warnings ;
 
-our $VERSION = 0.04 ;
+our $VERSION = 0.06 ;
 
 our @map ;
 $map[0] = "delta" ;
@@ -333,11 +333,16 @@ Manual install:
     use Perlsac::rwsac ;
     
     my %h = Perlsac::rwsac::rsac("example.sac") ;
-    
+
+		my $b = $h{b} ;
+		my $npts = $h{npts} ;
+		my $delta = $h{delta} ;
+
+		my @t = Perlsac::rwsac::calt($b,$npts,$delta) ;
+   
     for (my $n=0; $n<$h{npts}; $n++){
-        print "$h{t}[$n] $h{d}[$n]\n" ;
+        print "$t[$n] $h{d}[$n]\n" ;
     }
-    
 
 2. Dividing data by 'depmax' in headers and writing a new sac file.
 
@@ -363,22 +368,27 @@ Manual install:
     use warnings ;
     use Perlsac::rwsac ;
 
-		my $b = 0.0 ;
-		my $npts = 20 ;
-		my $delta = 0.1 ;
+    my $b = 0.0 ;
+    my $npts = 20 ;
+    my $delta = 0.1 ;
 
-		my %h = Perlsac::rwsac::init($b, $npts, $delta) ; #b, npts, delta
-		#$h{d} are zero-padded.
+    my %h = Perlsac::rwsac::init($b, $npts, $delta) ; #b, npts, delta
+    #$h{d} are zero-padded.
+
+    my @ys = (
+      0,0,0,0,0,
+      1,2,3,4,5,
+      4,3,2,1,0,
+      0,0,0,0,0) ;
+
+    $h{d} = [@ys] ;
+   
+    &Perlsac::rwsac::wsac('triangle.sac',%h) ;
+
+=head1 Limitations
+1. Type of files (IFTYPE and LEVEN) are not be well addressed yet.
 
-		my @ys = (
-			0,0,0,0,0,
-			1,2,3,4,5,
-			4,3,2,1,0,
-			0,0,0,0,0) ;
 
-		$h{d} = [@ys] ;
-	 
-		&Perlsac::rwsac::wsac('triangle.sac',%h) ;
 
 =cut
 
